@@ -21,7 +21,7 @@ class SharedDetails(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -45,7 +45,7 @@ class SharedDetails(object):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.__name
@@ -69,7 +69,7 @@ class SharedDetails(object):
 		The method to get the type
 
 		Returns:
-			string: A string value
+			string: A string representing the type
 		"""
 
 		return self.__type
@@ -93,7 +93,7 @@ class SharedDetails(object):
 		The method to get the subordinates
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the subordinates
 		"""
 
 		return self.__subordinates
@@ -120,7 +120,7 @@ class SharedDetails(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
